@@ -12,7 +12,6 @@ from datadog_lambda.extension import should_use_extension, flush_extension
 from datadog_lambda.cold_start import set_cold_start, is_cold_start
 from datadog_lambda.constants import XraySubsegment, TraceContextSource
 from datadog_lambda.metric import (
-    init_lambda_stats,
     flush_stats,
     submit_invocations_metric,
     submit_errors_metric,
@@ -111,6 +110,11 @@ class _LambdaDecorator(object):
             if self.logs_injection:
                 inject_correlation_ids()
 
+            # This prevents a breaking change in ddtrace v0.49 regarding the service name
+            # in requests-related spans
+            os.environ["DD_REQUESTS_SERVICE_NAME"] = os.environ.get(
+                "DD_SERVICE", "aws.lambda"
+            )
             # Patch third-party libraries for tracing
             patch_all()
 
@@ -120,7 +124,6 @@ class _LambdaDecorator(object):
 
     def __call__(self, event, context, **kwargs):
         """Executes when the wrapped function gets called"""
-        init_lambda_stats()
         self._before(event, context)
         try:
             self.response = self.func(event, context, **kwargs)
